@@ -130,6 +130,9 @@ struct Formatter
 {
   void init(const char* fmt);
   void print(void* logger_handle, ::ros::console::Level level, const char* str, const char* file, const char* function, int line);
+  std::string getTokenStrings(
+    void *logger_handle, ::ros::console::Level level, const char *str,
+    const char *file, const char *function, int line) const;
   std::string format_;
   V_Token tokens_;
 };
@@ -273,7 +276,7 @@ ROSCONSOLE_DECL std::string formatToString(const char* fmt, ...);
 } // namespace console
 } // namespace ros
 
-#ifdef WIN32
+#if defined(_MSC_VER)
 #define ROS_LIKELY(x)       (x)
 #define ROS_UNLIKELY(x)     (x)
 #else
@@ -281,7 +284,7 @@ ROSCONSOLE_DECL std::string formatToString(const char* fmt, ...);
 #define ROS_UNLIKELY(x)     __builtin_expect((x),0)
 #endif
 
-#if defined(MSVC)
+#if defined(_MSC_VER)
   #define __ROSCONSOLE_FUNCTION__ __FUNCSIG__
 #elif defined(__GNUC__)
   #define __ROSCONSOLE_FUNCTION__ __PRETTY_FUNCTION__
